/*
#   noisegate.h: the noisegate used by IDJC.
#   Copyright (C) 2005-2006 Stephen Fairchild (s-fairchild@users.sourceforge.net)
#
#   This program is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program in the file entitled COPYING.
#   If not, see <http://www.gnu.org/licenses/>.
*/

#include <jack/jack.h>

typedef jack_default_audio_sample_t ngate_t;

struct noisegate
   {
   /* supplied settings */
   ngate_t thresh;
   ngate_t hyster;
   int offdelay;
   ngate_t attenuation;
   ngate_t ontime;
   ngate_t offtime;
   /* working variables */
   int delaycount;
   ngate_t gain;
   int mute_state;
   };
   
ngate_t noisegate(struct noisegate *self, ngate_t signal);
